dados *Beta*
================

Random word generator

Please ★ this repo if you found it useful ★ ★ ★


Contributing
------------

1. Fork it!
2. Create your feature branch: ``git checkout -b my-new-feature``
3. Commit your changes: ``git commit -m 'Add some feature'``
4. Push to the branch: ``git push origin my-new-feature``
5. Submit a pull request :D


License
-------

`MIT License`_

`Jam Risser`_ © 2017


Credits
-------

-  `Jam Risser`_ - Author
